# Security Policy

## Supported Versions

Only the latest version of the software is supported.

All versions comes with no warranty.

## Reporting a Vulnerability

If you have detected a vulnerability, please contact ManoMano Security Team..

Please check our [Vulnerability reporting policy](https://security-s3-public.s3.eu-west-1.amazonaws.com/Vulnerability%20reporting%20policy.txt) and [contacts details](https://www.manomano.com/security.txt).

> This project is out-of-scope of the ManoMano Bug Bounty Program.
